diff --git a/Dalamud/Game/ClientState/Objects/Types/BattleChara.cs b/Dalamud/Game/ClientState/Objects/Types/BattleChara.cs
index 3d6707ddf..fbb10561e 100644
--- a/Dalamud/Game/ClientState/Objects/Types/BattleChara.cs
+++ b/Dalamud/Game/ClientState/Objects/Types/BattleChara.cs
@@ -40,12 +40,10 @@ internal BattleChara(IntPtr address)
public float CurrentCastTime => this.Struct->GetCastInfo()->CurrentCastTime;
///
- [Api10ToDo("Rename so it is not confused with AdjustedTotalCastTime")]
- public float TotalCastTime => this.Struct->GetCastInfo()->TotalCastTime;
+ public float BaseCastTime => this.Struct->GetCastInfo()->BaseCastTime;
///
- [Api10ToDo("Rename so it is not confused with TotalCastTime")]
- public float AdjustedTotalCastTime => this.Struct->GetCastInfo()->AdjustedTotalCastTime;
+ public float TotalCastTime => this.Struct->GetCastInfo()->TotalCastTime;
///
/// Gets the underlying structure.
@@ -94,19 +92,16 @@ public interface IBattleChara : ICharacter
public float CurrentCastTime { get; }
///
/// Gets the total casting time of the spell being cast by the chara.
///
///
/// This can only be a portion of the total cast for some actions.
- /// Use AdjustedTotalCastTime if you always need the total cast time.
+ /// Use TotalCastTime if you always need the total cast time.
///
- public float TotalCastTime { get; }
+ public float BaseCastTime { get; }
///
- /// Gets the plus any adjustments from the game, such as Action offset 2B. Used for display purposes.
+ /// Gets the plus any adjustments from the game, such as Action offset 2B. Used for display purposes.
///
- ///
- /// This is the actual total cast time for all actions.
- ///
- public float AdjustedTotalCastTime { get; }
+ public float TotalCastTime { get; }
}
@@ -94,19 +92,16 @@ public interface IBattleChara : ICharacter
public float CurrentCastTime { get; }
///
- /// Gets the total casting time of the spell being cast by the chara.
+ /// Gets the base casting time of the spell being cast by the chara.
///
///